@@ -2,7 +2,7 @@ package mRuby;
 use strict;
 use warnings;
 use 5.008008;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use XSLoader;
 
@@ -13,6 +13,8 @@ __END__
 
 =encoding utf8
 
+=for stopwords mruby
+
 =head1 NAME
 
 mRuby - mruby binding for perl5.
@@ -23,9 +25,9 @@ mRuby - mruby binding for perl5.
 
     my $mrb = mRuby::State->new();
     my $st = $mrb->parse_string('9');
-    my $n = $mrb->generate_code($st);
+    my $proc = $mrb->generate_code($st);
     $st->pool_close();
-    my $ret = $mrb->run($mrb->proc_new($n), undef);
+    my $ret = $mrb->run($proc, undef);
 
 =head1 DESCRIPTION
 
